@@ -39,7 +39,7 @@ EXPORT_KONTACT_PLUGIN_WITH_JSON(KOrganizerPlugin, "korganizerplugin.json")
 KOrganizerPlugin::KOrganizerPlugin(KontactInterface::Core *core, const KPluginMetaData &data, const QVariantList &)
     : KontactInterface::Plugin(core, core, data, "korganizer", "calendar")
 {
-    setComponentName(QStringLiteral("korganizer"), i18n("KOrganizer"));
+    setComponentName(QStringLiteral("korganizer"), i18nc("@info/plain", "KOrganizer"));
 
     auto action = new QAction(QIcon::fromTheme(QStringLiteral("appointment-new")), i18nc("@action:inmenu", "New Event…"), this);
     actionCollection()->addAction(QStringLiteral("new_event"), action);
@@ -132,10 +132,10 @@ void KOrganizerPlugin::processDropEvent(QDropEvent *event)
 
         KContacts::Addressee::List::ConstIterator it;
 
-        KContacts::Addressee::List::ConstIterator end(contacts.constEnd());
+        const KContacts::Addressee::List::ConstIterator end(contacts.constEnd());
         QStringList attendees;
         for (it = contacts.constBegin(); it != end; ++it) {
-            QString email = (*it).fullEmail();
+            const QString email = (*it).fullEmail();
             if (email.isEmpty()) {
                 attendees.append((*it).realName() + QStringLiteral("<>"));
             } else {
@@ -148,13 +148,13 @@ void KOrganizerPlugin::processDropEvent(QDropEvent *event)
     }
 
     if (KCalUtils::ICalDrag::canDecode(event->mimeData())) {
-        KCalendarCore::MemoryCalendar::Ptr cal(new KCalendarCore::MemoryCalendar(QTimeZone::systemTimeZone()));
+        const KCalendarCore::MemoryCalendar::Ptr cal(new KCalendarCore::MemoryCalendar(QTimeZone::systemTimeZone()));
         if (KCalUtils::ICalDrag::fromMimeData(event->mimeData(), cal)) {
             KCalendarCore::Incidence::List incidences = cal->incidences();
             Q_ASSERT(incidences.count());
             if (!incidences.isEmpty()) {
                 event->accept();
-                KCalendarCore::Incidence::Ptr i = incidences.first();
+                const KCalendarCore::Incidence::Ptr &i = incidences.first();
                 QString summary;
                 if (i->type() == KCalendarCore::Incidence::TypeJournal) {
                     summary = i18nc("@item", "Note: %1", i->summary());
@@ -169,7 +169,8 @@ void KOrganizerPlugin::processDropEvent(QDropEvent *event)
     }
 
     if (md->hasUrls()) {
-        for (const auto &url : md->urls()) {
+        const auto urls = md->urls();
+        for (const auto &url : urls) {
             if (url.scheme() == QLatin1StringView("akonadi") && url.hasQuery()) {
                 const QUrlQuery query(url.query());
                 if (!query.queryItemValue(QStringLiteral("item")).isEmpty()
@@ -186,16 +187,19 @@ void KOrganizerPlugin::processDropEvent(QDropEvent *event)
                         for (const Akonadi::Item &item : items) {
                             if (item.mimeType() == QLatin1StringView("message/rfc822")) {
                                 auto mail = item.payload<KMime::Message::Ptr>();
-                                interface()->openEventEditor(i18nc("Event from email summary", "Mail: %1", mail->subject()->asUnicodeString()),
-                                                             i18nc("Event from email content",
-                                                                   "<b>From:</b> %1<br /><b>To:</b> %2<br /><b>Subject:</b> %3",
-                                                                   mail->from()->displayString(),
-                                                                   mail->to()->displayString(),
-                                                                   mail->subject()->asUnicodeString()),
-                                                             url.toDisplayString(),
-                                                             QString(),
-                                                             QStringList(),
-                                                             QStringLiteral("message/rfc822"));
+                                interface()->openEventEditor(
+                                    i18nc("@info/plain event summary from email subject", "Mail: %1", mail->subject()->asUnicodeString()),
+                                    xi18nc("@info event description from email content",
+                                           "<emphasis>From:</emphasis> %1<nl/>"
+                                           "<emphasis>To:</emphasis> %2<nl/>"
+                                           "<emphasis>Subject:</emphasis> %3",
+                                           mail->from()->displayString(),
+                                           mail->to()->displayString(),
+                                           mail->subject()->asUnicodeString()),
+                                    url.toDisplayString(),
+                                    QString(),
+                                    QStringList(),
+                                    QStringLiteral("message/rfc822"));
                             }
                         }
                     });
