@@ -35,12 +35,12 @@ EXPORT_KONTACT_PLUGIN_WITH_JSON(TodoPlugin, "todoplugin.json")
 TodoPlugin::TodoPlugin(KontactInterface::Core *core, const KPluginMetaData &data, const QVariantList &)
     : KontactInterface::Plugin(core, core, data, "korganizer", "todo")
 {
-    setComponentName(QStringLiteral("korganizer"), i18n("KOrganizer"));
+    setComponentName(QStringLiteral("korganizer"), i18nc("@info/plain", "KOrganizer"));
 
     auto action = new QAction(QIcon::fromTheme(QStringLiteral("task-new")), i18nc("@action:inmenu", "New To-do…"), this);
     actionCollection()->addAction(QStringLiteral("new_todo"), action);
     actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_T));
-    QString str = i18nc("@info:status", "Create a new to-do");
+    QString const str = i18nc("@info:status", "Create a new to-do");
     action->setStatusTip(str);
     action->setToolTip(str);
 
@@ -132,7 +132,7 @@ void TodoPlugin::processDropEvent(QDropEvent *event)
         KContacts::Addressee::List::ConstIterator it;
 
         QStringList attendees;
-        KContacts::Addressee::List::ConstIterator end(contacts.constEnd());
+        KContacts::Addressee::List::ConstIterator const end(contacts.constEnd());
         for (it = contacts.constBegin(); it != end; ++it) {
             const QString email = (*it).fullEmail();
             if (email.isEmpty()) {
@@ -147,13 +147,13 @@ void TodoPlugin::processDropEvent(QDropEvent *event)
     }
 
     if (KCalUtils::ICalDrag::canDecode(event->mimeData())) {
-        KCalendarCore::MemoryCalendar::Ptr cal(new KCalendarCore::MemoryCalendar(QTimeZone::systemTimeZone()));
+        KCalendarCore::MemoryCalendar::Ptr const cal(new KCalendarCore::MemoryCalendar(QTimeZone::systemTimeZone()));
         if (KCalUtils::ICalDrag::fromMimeData(event->mimeData(), cal)) {
             KCalendarCore::Incidence::List incidences = cal->incidences();
             Q_ASSERT(incidences.count());
             if (!incidences.isEmpty()) {
                 event->accept();
-                KCalendarCore::Incidence::Ptr i = incidences.first();
+                KCalendarCore::Incidence::Ptr const &i = incidences.first();
                 QString summary;
                 if (i->type() == KCalendarCore::Incidence::TypeJournal) {
                     summary = i18nc("@item", "Note: %1", i->summary());
@@ -168,7 +168,8 @@ void TodoPlugin::processDropEvent(QDropEvent *event)
     }
 
     if (md->hasUrls()) {
-        for (const auto &url : md->urls()) {
+        const auto urls = md->urls();
+        for (const auto &url : urls) {
             if (url.scheme() == QLatin1StringView("akonadi") && url.hasQuery()) {
                 const QUrlQuery query(url.query());
                 if (!query.queryItemValue(QStringLiteral("item")).isEmpty()
@@ -185,16 +186,19 @@ void TodoPlugin::processDropEvent(QDropEvent *event)
                         for (const Akonadi::Item &item : items) {
                             if (item.mimeType() == QLatin1StringView("message/rfc822")) {
                                 auto mail = item.payload<KMime::Message::Ptr>();
-                                interface()->openTodoEditor(i18nc("Event from email summary", "Mail: %1", mail->subject()->asUnicodeString()),
-                                                            i18nc("Event from email content",
-                                                                  "<b>From:</b> %1<br /><b>To:</b> %2<br /><b>Subject:</b> %3",
-                                                                  mail->from()->displayString(),
-                                                                  mail->to()->displayString(),
-                                                                  mail->subject()->asUnicodeString()),
-                                                            url.toDisplayString(),
-                                                            QString(),
-                                                            QStringList(),
-                                                            QStringLiteral("message/rfc822"));
+                                interface()->openTodoEditor(
+                                    i18nc("@info/plain to-do summary from email subjuect", "Mail: %1", mail->subject()->asUnicodeString()),
+                                    xi18nc("@info to-do description from email content",
+                                           "<emphasis>From:</emphasis> %1<nl/>"
+                                           "<emphasis>To:</emphasis> %2<nl/>"
+                                           "<emphasis>Subject:</emphasis> %3",
+                                           mail->from()->displayString(),
+                                           mail->to()->displayString(),
+                                           mail->subject()->asUnicodeString()),
+                                    url.toDisplayString(),
+                                    QString(),
+                                    QStringList(),
+                                    QStringLiteral("message/rfc822"));
                             }
                         }
                     });
